@@ -18,8 +18,6 @@
  *
  */
 
-#include "config.h"
-
 #include "gdm-dbus-util.h"
 #include <string.h>
 
@@ -54,8 +52,8 @@ handle_connection (GDBusServer      *server,
                    GDBusConnection  *new_connection,
                    gpointer          user_data)
 {
-        g_autoptr(GDBusNodeInfo) bus_info = NULL;
         GDBusInterfaceVTable bus_vtable = { handle_bus_method };
+        GDBusNodeInfo *bus_info;
 
         bus_info = g_dbus_node_info_new_for_xml (dbus_introspection,
                                                  NULL);
@@ -67,6 +65,7 @@ handle_connection (GDBusServer      *server,
                                            bus_info->interfaces[0],
                                            &bus_vtable,
                                            NULL, NULL, NULL);
+        g_dbus_node_info_unref (bus_info);
 
         /* We're not handling the signal */
         return FALSE;
@@ -76,23 +75,13 @@ GDBusServer *
 gdm_dbus_setup_private_server (GDBusAuthObserver  *observer,
                                GError            **error)
 {
-        g_autofree char *guid = NULL;
+        char *guid;
         const char *client_address;
-        g_autoptr(GDBusServer) server = NULL;
-
-        /* Ensure the private bus directory exists */
-        if (g_mkdir_with_parents (GDM_PRIVATE_DBUS_DIR, 0711) == -1) {
-                g_set_error_literal (error, G_IO_ERROR, g_io_error_from_errno (errno), g_strerror (errno));
-                return NULL;
-        }
-        if (g_chmod (GDM_PRIVATE_DBUS_DIR, 0711) == -1) {
-                g_set_error_literal (error, G_IO_ERROR, g_io_error_from_errno (errno), g_strerror (errno));
-                return NULL;
-        }
+        GDBusServer *server;
 
         guid = g_dbus_generate_guid ();
 
-        server = g_dbus_server_new_sync ("unix:dir=" GDM_PRIVATE_DBUS_DIR,
+        server = g_dbus_server_new_sync ("unix:tmpdir=/tmp",
                                          G_DBUS_SERVER_FLAGS_NONE,
                                          guid,
                                          observer,
@@ -110,7 +99,9 @@ gdm_dbus_setup_private_server (GDBusAuthObserver  *observer,
                           G_CALLBACK (handle_connection),
                           NULL);
 
-        return g_steal_pointer (&server);
+        g_free (guid);
+
+        return server;
 }
 
 gboolean
@@ -118,8 +109,9 @@ gdm_dbus_get_pid_for_name (const char  *system_bus_name,
                            pid_t       *out_pid,
                            GError     **error)
 {
-        g_autoptr(GDBusConnection) bus = NULL;
-        g_autoptr(GVariant) reply = NULL;
+        GDBusConnection *bus;
+        GVariant *reply;
+        gboolean retval = FALSE;
         unsigned int v;
 
         g_return_val_if_fail (system_bus_name != NULL, FALSE);
@@ -141,13 +133,18 @@ gdm_dbus_get_pid_for_name (const char  *system_bus_name,
                                              -1,
                                              NULL, error);
         if (reply == NULL) {
-                return FALSE;
+                goto out;
         }
 
         g_variant_get (reply, "(u)", &v);
         *out_pid = v;
+        g_variant_unref (reply);
 
-        return TRUE;
+        retval = TRUE;
+ out:
+        g_object_unref (bus);
+
+        return retval;
 }
 
 gboolean
@@ -155,8 +152,9 @@ gdm_dbus_get_uid_for_name (const char  *system_bus_name,
                            uid_t       *out_uid,
                            GError     **error)
 {
-        g_autoptr(GDBusConnection) bus = NULL;
-        g_autoptr(GVariant) reply = NULL;
+        GDBusConnection *bus;
+        GVariant *reply;
+        gboolean retval = FALSE;
         unsigned int v;
 
         g_return_val_if_fail (system_bus_name != NULL, FALSE);
@@ -178,13 +176,18 @@ gdm_dbus_get_uid_for_name (const char  *system_bus_name,
                                              -1,
                                              NULL, error);
         if (reply == NULL) {
-                return FALSE;
+                goto out;
         }
 
         g_variant_get (reply, "(u)", &v);
         *out_uid = v;
+        g_variant_unref (reply);
 
-        return TRUE;
+        retval = TRUE;
+ out:
+        g_object_unref (bus);
+
+        return retval;
 }
 
 void
