@@ -34,17 +34,14 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 
-#ifdef ENABLE_X11_SUPPORT
 #include <xcb/xcb.h>
 #include <X11/Xlib.h>
-#endif
 
 #include "gdm-common.h"
 #include "gdm-display.h"
 #include "gdm-display-glue.h"
 #include "gdm-display-access-file.h"
 #include "gdm-launch-environment.h"
-#include "gdm-remote-display.h"
 
 #include "gdm-settings-direct.h"
 #include "gdm-settings-keys.h"
@@ -76,10 +73,8 @@ typedef struct _GdmDisplayPrivate
 
         guint                 finish_idle_id;
 
-#ifdef ENABLE_X11_SUPPORT
         xcb_connection_t     *xcb_connection;
         int                   xcb_screen_number;
-#endif
 
         GDBusConnection      *connection;
         GdmDisplayAccessFile *user_access_file;
@@ -198,8 +193,8 @@ gboolean
 gdm_display_create_authority (GdmDisplay *self)
 {
         GdmDisplayPrivate    *priv;
-        g_autoptr(GdmDisplayAccessFile) access_file = NULL;
-        g_autoptr(GError) error = NULL;
+        GdmDisplayAccessFile *access_file;
+        GError               *error;
         gboolean              res;
 
         g_return_val_if_fail (GDM_IS_DISPLAY (self), FALSE);
@@ -207,10 +202,12 @@ gdm_display_create_authority (GdmDisplay *self)
         priv = gdm_display_get_instance_private (self);
         g_return_val_if_fail (priv->access_file == NULL, FALSE);
 
+        error = NULL;
         access_file = _create_access_file_for_user (self, GDM_USERNAME, &error);
 
         if (access_file == NULL) {
                 g_critical ("could not create display access file: %s", error->message);
+                g_error_free (error);
                 return FALSE;
         }
 
@@ -223,17 +220,19 @@ gdm_display_create_authority (GdmDisplay *self)
                                                    &error);
 
         if (! res) {
+
                 g_critical ("could not add display to access file: %s", error->message);
+                g_error_free (error);
                 gdm_display_access_file_close (access_file);
+                g_object_unref (access_file);
                 return FALSE;
         }
 
-        priv->access_file = g_steal_pointer (&access_file);
+        priv->access_file = access_file;
 
         return TRUE;
 }
 
-#ifdef ENABLE_X11_SUPPORT
 static void
 setup_xhost_auth (XHostAddress              *host_entries)
 {
@@ -247,7 +246,6 @@ setup_xhost_auth (XHostAddress              *host_entries)
         host_entries[2].address   = "localuser\0gnome-initial-setup";
         host_entries[2].length    = sizeof ("localuser\0gnome-initial-setup");
 }
-#endif
 
 gboolean
 gdm_display_add_user_authorization (GdmDisplay *self,
@@ -255,10 +253,9 @@ gdm_display_add_user_authorization (GdmDisplay *self,
                                     char      **filename,
                                     GError    **error)
 {
-#ifdef ENABLE_X11_SUPPORT
         GdmDisplayPrivate    *priv;
-        g_autoptr(GdmDisplayAccessFile) access_file = NULL;
-        g_autoptr(GError) access_file_error = NULL;
+        GdmDisplayAccessFile *access_file;
+        GError               *access_file_error;
         gboolean              res;
 
         int                       i;
@@ -283,12 +280,13 @@ gdm_display_add_user_authorization (GdmDisplay *self,
 
         g_debug ("GdmDisplay: Adding user authorization for %s", username);
 
+        access_file_error = NULL;
         access_file = _create_access_file_for_user (self,
                                                     username,
                                                     &access_file_error);
 
         if (access_file == NULL) {
-                g_propagate_error (error, g_steal_pointer (&access_file_error));
+                g_propagate_error (error, access_file_error);
                 return FALSE;
         }
 
@@ -301,13 +299,14 @@ gdm_display_add_user_authorization (GdmDisplay *self,
                 g_debug ("GdmDisplay: Unable to add user authorization for %s: %s",
                          username,
                          access_file_error->message);
-                g_propagate_error (error, g_steal_pointer (&access_file_error));
+                g_propagate_error (error, access_file_error);
                 gdm_display_access_file_close (access_file);
+                g_object_unref (access_file);
                 return FALSE;
         }
 
         *filename = gdm_display_access_file_get_path (access_file);
-        priv->user_access_file = g_steal_pointer (&access_file);
+        priv->user_access_file = access_file;
 
         g_debug ("GdmDisplay: Added user authorization for %s: %s", username, *filename);
         /* Remove access for the programs run by greeter now that the
@@ -335,9 +334,6 @@ gdm_display_add_user_authorization (GdmDisplay *self,
         }
 
         return TRUE;
-#else
-    return FALSE;
-#endif
 }
 
 gboolean
@@ -637,7 +633,6 @@ gdm_display_finish (GdmDisplay *self)
 static void
 gdm_display_disconnect (GdmDisplay *self)
 {
-#ifdef ENABLE_X11_SUPPORT
         GdmDisplayPrivate *priv;
         /* These 3 bits are reserved/unused by the X protocol */
         guint32 unused_bits = 0b11100000000000000000000000000000;
@@ -671,7 +666,6 @@ gdm_display_disconnect (GdmDisplay *self)
         xcb_flush (priv->xcb_connection);
 
         g_clear_pointer (&priv->xcb_connection, xcb_disconnect);
-#endif
 }
 
 gboolean
@@ -1052,11 +1046,7 @@ gdm_display_get_property (GObject        *object,
                 g_value_set_boolean (value, priv->is_local);
                 break;
         case PROP_IS_CONNECTED:
-#ifdef ENABLE_X11_SUPPORT
                 g_value_set_boolean (value, priv->xcb_connection != NULL);
-#else
-                g_value_set_boolean (value, FALSE);
-#endif
                 break;
         case PROP_LAUNCH_ENVIRONMENT:
                 g_value_set_object (value, priv->launch_environment);
@@ -1090,12 +1080,13 @@ handle_get_id (GdmDBusDisplay        *skeleton,
                GDBusMethodInvocation *invocation,
                GdmDisplay            *self)
 {
-        g_autofree char *id = NULL;
+        char *id;
 
         gdm_display_get_id (self, &id, NULL);
 
         gdm_dbus_display_complete_get_id (skeleton, invocation, id);
 
+        g_free (id);
         return TRUE;
 }
 
@@ -1104,7 +1095,7 @@ handle_get_remote_hostname (GdmDBusDisplay        *skeleton,
                             GDBusMethodInvocation *invocation,
                             GdmDisplay            *self)
 {
-        g_autofree char *hostname = NULL;
+        char *hostname;
 
         gdm_display_get_remote_hostname (self, &hostname, NULL);
 
@@ -1112,6 +1103,7 @@ handle_get_remote_hostname (GdmDBusDisplay        *skeleton,
                                                        invocation,
                                                        hostname ? hostname : "");
 
+        g_free (hostname);
         return TRUE;
 }
 
@@ -1120,8 +1112,9 @@ handle_get_seat_id (GdmDBusDisplay        *skeleton,
                     GDBusMethodInvocation *invocation,
                     GdmDisplay            *self)
 {
-        g_autofree char *seat_id = NULL;
+        char *seat_id;
 
+        seat_id = NULL;
         gdm_display_get_seat_id (self, &seat_id, NULL);
 
         if (seat_id == NULL) {
@@ -1129,6 +1122,7 @@ handle_get_seat_id (GdmDBusDisplay        *skeleton,
         }
         gdm_dbus_display_complete_get_seat_id (skeleton, invocation, seat_id);
 
+        g_free (seat_id);
         return TRUE;
 }
 
@@ -1137,12 +1131,13 @@ handle_get_x11_display_name (GdmDBusDisplay        *skeleton,
                              GDBusMethodInvocation *invocation,
                              GdmDisplay            *self)
 {
-        g_autofree char *name = NULL;
+        char *name;
 
         gdm_display_get_x11_display_name (self, &name, NULL);
 
         gdm_dbus_display_complete_get_x11_display_name (skeleton, invocation, name);
 
+        g_free (name);
         return TRUE;
 }
 
@@ -1178,13 +1173,15 @@ static gboolean
 register_display (GdmDisplay *self)
 {
         GdmDisplayPrivate *priv;
-        g_autoptr(GError) error = NULL;
+        GError *error = NULL;
 
         priv = gdm_display_get_instance_private (self);
 
+        error = NULL;
         priv->connection = g_bus_get_sync (G_BUS_TYPE_SYSTEM, NULL, &error);
         if (priv->connection == NULL) {
                 g_critical ("error getting system bus: %s", error->message);
+                g_error_free (error);
                 exit (EXIT_FAILURE);
         }
 
@@ -1488,11 +1485,12 @@ static void
 on_launch_environment_session_opened (GdmLaunchEnvironment *launch_environment,
                                       GdmDisplay           *self)
 {
-        g_autofree char *session_id = NULL;
+        char       *session_id;
 
         g_debug ("GdmDisplay: Greeter session opened");
         session_id = gdm_launch_environment_get_session_id (launch_environment);
-        g_object_set (G_OBJECT (self), "session-id", session_id, NULL);
+        _gdm_display_set_session_id (self, session_id);
+        g_free (session_id);
 }
 
 static void
@@ -1545,12 +1543,14 @@ on_launch_environment_session_died (GdmLaunchEnvironment *launch_environment,
 static gboolean
 can_create_environment (const char *session_id)
 {
-        g_autofree char *path = NULL;
+        char *path;
         gboolean session_exists;
 
         path = g_strdup_printf (GNOME_SESSION_SESSIONS_PATH "/%s.session", session_id);
         session_exists = g_file_test (path, G_FILE_TEST_EXISTS);
 
+        g_free (path);
+
         return session_exists;
 }
 
@@ -1570,9 +1570,9 @@ kernel_cmdline_initial_setup_argument (const gchar  *contents,
                                        gchar       **initial_setup_argument,
                                        GError      **error)
 {
-        g_autoptr(GRegex) regex = NULL;
-        g_autoptr(GMatchInfo) match_info = NULL;
-        g_autofree gchar *match_group = NULL;
+        GRegex *regex = NULL;
+        GMatchInfo *match_info = NULL;
+        gchar *match_group = NULL;
 
         g_return_val_if_fail (initial_setup_argument != NULL, FALSE);
 
@@ -1582,6 +1582,9 @@ kernel_cmdline_initial_setup_argument (const gchar  *contents,
             return FALSE;
 
         if (!g_regex_match (regex, contents, 0, &match_info)) {
+                g_free (match_info);
+                g_free (regex);
+
                 g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                              "Could not match gnome.initial-setup= in kernel cmdline");
 
@@ -1591,13 +1594,19 @@ kernel_cmdline_initial_setup_argument (const gchar  *contents,
         match_group = g_match_info_fetch (match_info, 1);
 
         if (!match_group) {
+                g_free (match_info);
+                g_free (regex);
+
                 g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
                              "Could not match gnome.initial-setup= in kernel cmdline");
 
                 return FALSE;
         }
 
-        *initial_setup_argument = g_steal_pointer (&match_group);
+        *initial_setup_argument = match_group;
+
+        g_free (match_info);
+        g_free (regex);
 
         return TRUE;
 }
@@ -1607,15 +1616,16 @@ kernel_cmdline_initial_setup_argument (const gchar  *contents,
 static gboolean
 kernel_cmdline_initial_setup_force_state (gboolean *force_state)
 {
-        g_autoptr(GError) error = NULL;
-        g_autofree gchar *contents = NULL;
-        g_autofree gchar *setup_argument = NULL;
+        GError *error = NULL;
+        gchar *contents = NULL;
+        gchar *setup_argument = NULL;
 
         g_return_val_if_fail (force_state != NULL, FALSE);
 
         if (!g_file_get_contents ("/proc/cmdline", &contents, NULL, &error)) {
                 g_debug ("GdmDisplay: Could not check kernel parameters, not forcing initial setup: %s",
                           error->message);
+                g_clear_error (&error);
                 return FALSE;
         }
 
@@ -1623,12 +1633,16 @@ kernel_cmdline_initial_setup_force_state (gboolean *force_state)
 
         if (!kernel_cmdline_initial_setup_argument (contents, &setup_argument, &error)) {
                 g_debug ("GdmDisplay: Failed to read kernel commandline: %s", error->message);
+                g_clear_pointer (&contents, g_free);
                 return FALSE;
         }
 
+        g_clear_pointer (&contents, g_free);
+
         /* Poor-man's check for truthy or falsey values */
         *force_state = setup_argument[0] == '1';
 
+        g_free (setup_argument);
         return TRUE;
 }
 
@@ -1678,41 +1692,15 @@ wants_initial_setup (GdmDisplay *self)
         return enabled;
 }
 
-gboolean
-gdm_display_prepare_greeter_session (GdmDisplay          *self,
-                                     GdmDynamicUserStore *dyn_user_store,
-                                     uid_t               *ret_uid)
-{
-        g_autoptr (GError) error = NULL;
-        GdmDisplayPrivate *priv;
-        uid_t uid;
-
-        g_return_val_if_fail (GDM_IS_DISPLAY (self), FALSE);
-        priv = gdm_display_get_instance_private (self);
-        g_return_val_if_fail (g_strcmp0 (priv->session_class, "greeter") == 0, FALSE);
-
-        if (!gdm_launch_environment_ensure_uid (priv->launch_environment,
-                                                dyn_user_store, &uid, &error)) {
-                g_warning ("GdmDisplay: Failed to allocate UID for greeter: %s",
-                           error->message);
-                return FALSE;
-        }
-
-        if (ret_uid != NULL)
-                *ret_uid = uid;
-
-        return TRUE;
-}
-
 void
 gdm_display_start_greeter_session (GdmDisplay *self)
 {
         GdmDisplayPrivate *priv;
         GdmSession    *session;
-        g_autofree char *display_name = NULL;
-        g_autofree char *seat_id = NULL;
-        g_autofree char *hostname = NULL;
-        g_autofree char *auth_file = NULL;
+        char          *display_name;
+        char          *seat_id;
+        char          *hostname;
+        char          *auth_file = NULL;
 
         g_return_if_fail (GDM_IS_DISPLAY (self));
 
@@ -1721,6 +1709,10 @@ gdm_display_start_greeter_session (GdmDisplay *self)
 
         g_debug ("GdmDisplay: Running greeter");
 
+        display_name = NULL;
+        seat_id = NULL;
+        hostname = NULL;
+
         g_object_get (self,
                       "x11-display-name", &display_name,
                       "seat-id", &seat_id,
@@ -1766,6 +1758,11 @@ gdm_display_start_greeter_session (GdmDisplay *self)
                       "display-is-initial", priv->is_initial,
                       "supported-session-types", priv->supported_session_types,
                       NULL);
+
+        g_free (display_name);
+        g_free (seat_id);
+        g_free (hostname);
+        g_free (auth_file);
 }
 
 void
@@ -1799,7 +1796,6 @@ gdm_display_stop_greeter_session (GdmDisplay *self)
         }
 }
 
-#ifdef ENABLE_X11_SUPPORT
 static xcb_window_t
 get_root_window (xcb_connection_t *connection,
                  int               screen_number)
@@ -1883,12 +1879,10 @@ out:
         g_clear_pointer (&atom_reply, free);
         g_clear_pointer (&get_property_reply, free);
 }
-#endif
 
 gboolean
 gdm_display_connect (GdmDisplay *self)
 {
-#ifdef ENABLE_X11_SUPPORT
         GdmDisplayPrivate *priv;
         xcb_auth_info_t *auth_info = NULL;
         gboolean ret;
@@ -1962,7 +1956,5 @@ gdm_display_connect (GdmDisplay *self)
         }
 
         return ret;
-#else
-    return FALSE;
-#endif
 }
+
