@@ -93,11 +93,14 @@ static gboolean
 gdm_legacy_display_prepare (GdmDisplay *display)
 {
         GdmLegacyDisplay *self = GDM_LEGACY_DISPLAY (display);
-        g_autoptr(GdmLaunchEnvironment) launch_environment = NULL;
-        g_autofree char *display_name = NULL;
-        g_autofree gchar *seat_id = NULL;
+        GdmLaunchEnvironment *launch_environment;
+        char          *display_name;
+        char          *seat_id;
         gboolean       doing_initial_setup = FALSE;
 
+        display_name = NULL;
+        seat_id = NULL;
+
         g_object_get (self,
                       "x11-display-name", &display_name,
                       "seat-id", &seat_id,
@@ -119,6 +122,7 @@ gdm_legacy_display_prepare (GdmDisplay *display)
         }
 
         g_object_set (self, "launch-environment", launch_environment, NULL);
+        g_object_unref (launch_environment);
 
         if (!gdm_display_create_authority (display)) {
                 g_warning ("Unable to set up access control for display %s",
@@ -141,8 +145,8 @@ on_server_ready (GdmServer       *server,
                 g_debug ("GdmDisplay: could not connect to display");
                 gdm_display_unmanage (GDM_DISPLAY (self));
         } else {
-                g_autoptr(GdmLaunchEnvironment) launch_environment = NULL;
-                g_autofree char *display_device = NULL;
+                GdmLaunchEnvironment *launch_environment;
+                char *display_device;
 
                 display_device = gdm_server_get_display_device (server);
 
@@ -153,6 +157,8 @@ on_server_ready (GdmServer       *server,
                               "x11-display-device",
                               display_device,
                               NULL);
+                g_clear_pointer(&display_device, g_free);
+                g_clear_object (&launch_environment);
 
                 g_debug ("GdmDisplay: connected to display");
                 g_object_set (G_OBJECT (self), "status", GDM_DISPLAY_MANAGED, NULL);
@@ -185,9 +191,9 @@ static void
 gdm_legacy_display_manage (GdmDisplay *display)
 {
         GdmLegacyDisplay *self = GDM_LEGACY_DISPLAY (display);
-        g_autofree char *display_name = NULL;
-        g_autofree char *auth_file = NULL;
-        g_autofree char *seat_id = NULL;
+        char            *display_name;
+        char            *auth_file;
+        char            *seat_id;
         gboolean         is_initial;
         gboolean         res;
         gboolean         disable_tcp;
@@ -201,6 +207,10 @@ gdm_legacy_display_manage (GdmDisplay *display)
 
         self->server = gdm_server_new (display_name, seat_id, auth_file, is_initial);
 
+        g_free (display_name);
+        g_free (auth_file);
+        g_free (seat_id);
+
         disable_tcp = TRUE;
         if (gdm_settings_direct_get_boolean (GDM_KEY_DISALLOW_TCP, &disable_tcp)) {
                 g_object_set (self->server,
@@ -280,13 +290,14 @@ GdmDisplay *
 gdm_legacy_display_new (int display_number)
 {
         GObject *object;
-        g_autofree char *x11_display = NULL;
+        char    *x11_display;
 
         x11_display = g_strdup_printf (":%d", display_number);
         object = g_object_new (GDM_TYPE_LEGACY_DISPLAY,
                                "x11-display-number", display_number,
                                "x11-display-name", x11_display,
                                NULL);
+        g_free (x11_display);
 
         return GDM_DISPLAY (object);
 }
