@@ -43,7 +43,6 @@
 #include "gdm-manager.h"
 #include "gdm-log.h"
 #include "gdm-common.h"
-#include "gdm-file-utils.h"
 
 #include "gdm-settings.h"
 #include "gdm-settings-direct.h"
@@ -145,22 +144,49 @@ write_pid (void)
         atexit (delete_pid);
 }
 
+static gboolean
+ensure_dir_with_perms (const char *path,
+                       uid_t       uid,
+                       gid_t       gid,
+                       mode_t      mode,
+                       GError    **error)
+{
+        gboolean ret = FALSE;
+
+        if (g_mkdir_with_parents (path, 0755) == -1) {
+                g_set_error_literal (error, G_IO_ERROR, g_io_error_from_errno (errno), g_strerror (errno));
+                goto out;
+        }
+        if (g_chmod (path, mode) == -1) {
+                g_set_error_literal (error, G_IO_ERROR, g_io_error_from_errno (errno), g_strerror (errno));
+                goto out;
+        }
+        if (chown (path, uid, gid) == -1) {
+                g_set_error_literal (error, G_IO_ERROR, g_io_error_from_errno (errno), g_strerror (errno));
+                goto out;
+        }
+
+        ret = TRUE;
+ out:
+        return ret;
+}
+
 static void
 gdm_daemon_ensure_dirs (uid_t uid,
                         gid_t gid)
 {
-        g_autoptr (GError) error = NULL;
+        GError *error = NULL;
 
-        /* Set up /run/gdm */
-        if (!gdm_ensure_dir (GDM_RUN_DIR, 0, 0, 0755, FALSE, &error)) {
-                g_warning ("Failed to create " GDM_RUN_DIR ": %s", error->message);
-                g_clear_error (&error);
+        /* Set up /var/run/gdm */
+        if (!ensure_dir_with_perms (GDM_RAN_ONCE_MARKER_DIR, 0, gid, 0711, &error)) {
+                gdm_fail (_("Failed to create ran once marker dir %s: %s"),
+                          GDM_RAN_ONCE_MARKER_DIR, error->message);
         }
 
         /* Set up /var/log/gdm */
-        if (!gdm_ensure_dir (LOGDIR, 0, gid, 0711, FALSE, &error)) {
-                g_warning ("Failed to create " LOGDIR ": %s", error->message);
-                g_clear_error (&error);
+        if (!ensure_dir_with_perms (LOGDIR, 0, gid, 0711, &error)) {
+                gdm_fail (_("Failed to create LogDir %s: %s"),
+                          LOGDIR, error->message);
         }
 }
 
@@ -194,25 +220,25 @@ gdm_daemon_lookup_user (uid_t *uidp,
 
         /* Set uid and gid */
         if G_UNLIKELY (pwent == NULL) {
-                g_critical (_("Can’t find the GDM user “%s”. Aborting!"), username);
+                gdm_fail (_("Can’t find the GDM user “%s”. Aborting!"), username);
         } else {
                 uid = pwent->pw_uid;
         }
 
         if G_UNLIKELY (uid == 0) {
-                g_critical (_("The GDM user should not be root. Aborting!"));
+                gdm_fail (_("The GDM user should not be root. Aborting!"));
         }
 
         grent = getgrnam (groupname);
 
         if G_UNLIKELY (grent == NULL) {
-                g_critical (_("Can’t find the GDM group “%s”. Aborting!"), groupname);
+                gdm_fail (_("Can’t find the GDM group “%s”. Aborting!"), groupname);
         } else  {
                 gid = grent->gr_gid;
         }
 
         if G_UNLIKELY (gid == 0) {
-                g_critical (_("The GDM group should not be root. Aborting!"));
+                gdm_fail (_("The GDM group should not be root. Aborting!"));
         }
 
         if (uidp != NULL) {
@@ -380,7 +406,6 @@ on_name_acquired (GDBusConnection *bus,
 {
         gboolean xdmcp_enabled;
         gboolean show_local_greeter;
-        gboolean remote_login_enabled;
 
         manager = gdm_manager_new ();
         if (manager == NULL) {
@@ -398,10 +423,6 @@ on_name_acquired (GDBusConnection *bus,
         gdm_settings_direct_get_boolean (GDM_KEY_XDMCP_ENABLE, &xdmcp_enabled);
         gdm_manager_set_xdmcp_enabled (manager, xdmcp_enabled);
 
-        remote_login_enabled = FALSE;
-        gdm_settings_direct_get_boolean (GDM_KEY_REMOTE_LOGIN_ENABLE, &remote_login_enabled);
-        gdm_manager_set_remote_login_enabled (manager, remote_login_enabled);
-
         gdm_manager_start (manager);
 }
 
